==> cscec5b-dataexchange-impl-3.0.0-20201102.035315-3-sources.jar: com/ejianc/business/dataexchange/service/impl/StordocService.java <==
package com.ejianc.business.dataexchange.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ejianc.business.dataexchange.mapper.StordocMapper;
import com.ejianc.business.dataexchange.service.IStordocService;
import com.ejianc.business.dataexchange.vo.Stordoc;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 仓库档案 服务实现类
 * </p>
 *
 * @author Brin
 * @since 2020-10-30 08:07:45
 */
@Service("stordocService")
public class StordocService extends ServiceImpl<StordocMapper, Stordoc> implements IStordocService {

    public List<Stordoc> queryStordocs(Page<Stordoc> page, QueryWrapper queryWrapper, Long supplierId) {
        List<Stordoc> list = baseMapper.page(page,queryWrapper,supplierId);
                //selectList(page,queryWrapper,supplierId);
        return list;
    }

 /*
    //仓库档案 列表接口（分页）
    @Override
    public Page<Stordoc> page(Page pages, StordocRequest request) {
        List<Stordoc> list = new ArrayList<>();
        list = baseMapper.page(pages, request);
        pages.setRecords(list);
        return pages;
    }
    
    //仓库档案 查询合计行
    @Override
    public Stordoc queryTotalRow(StordocRequest request) {
    	return baseMapper.queryTotalRow(request);
    }
    
    //仓库档案 导出所有数据
    @Override
    public List<Stordoc> selectListAll(StordocRequest request) {
        return baseMapper.selectListAll(request);
    }*/

}

==> cscec5b-dataexchange-impl-3.0.0-20210811.094329-104-sources.jar: com/ejianc/business/dataexchange/service/impl/StordocService.java <==
package com.ejianc.business.dataexchange.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ejianc.business.dataexchange.mapper.StordocMapper;
import com.ejianc.business.dataexchange.service.IStordocService;
import com.ejianc.business.dataexchange.vo.Stordoc;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 仓库档案 服务实现类
 * </p>
 *
 * @author Brin
 * @since 2020-10-30 08:07:45
 */
@Service("stordocService")
public class StordocService extends ServiceImpl<StordocMapper, Stordoc> implements IStordocService {

    public List<Stordoc> queryStordocs(Page<Stordoc> page, QueryWrapper queryWrapper, Long supplierId, String pkCorp) {
        List<Stordoc> list = baseMapper.page(page,queryWrapper,supplierId, pkCorp);
                //selectList(page,queryWrapper,supplierId);
        return list;
    }

 /*
    //仓库档案 列表接口（分页）
    @Override
    public Page<Stordoc> page(Page pages, StordocRequest request) {
        List<Stordoc> list = new ArrayList<>();
        list = baseMapper.page(pages, request);
        pages.setRecords(list);
        return pages;
    }
    
    //仓库档案 查询合计行
    @Override
    public Stordoc queryTotalRow(StordocRequest request) {
    	return baseMapper.queryTotalRow(request);
    }
    
    //仓库档案 导出所有数据
    @Override
    public List<Stordoc> selectListAll(StordocRequest request) {
        return baseMapper.selectListAll(request);
    }*/

}
